// src/helptips/HelpTooltips.tsx
import { useCallback } from "react";
import { useDispatch, useSelector } from "react-redux";
import { ConfigurationObject, DocsLink, HelpTooltip, LogDialog } from "@northern.tech/common-ui";
import storeActions from "@northern.tech/store/actions";
import { READ_STATES, yes } from "@northern.tech/store/constants";
import { getDeviceById, getFeatures, getTooltipsState } from "@northern.tech/store/selectors";
import { setAllTooltipsReadState, setTooltipReadState } from "@northern.tech/store/thunks";
import { Fragment, jsx, jsxs } from "react/jsx-runtime";
var { setSnackbar } = storeActions;
var AuthExplainButton = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  /* @__PURE__ */ jsx(LogDialog, {}),
  /* @__PURE__ */ jsx("h3", { children: "Device authorization status" }),
  /* @__PURE__ */ jsx("p", { children: "Each device sends an authentication request containing its identity attributes and its current public key. You can accept, reject or dismiss these requests to determine the authorization status of the device." }),
  /* @__PURE__ */ jsxs("p", { children: [
    "In cases such as key rotation, each device may have more than one identity/key combination listed. See the documentation for more on",
    " ",
    /* @__PURE__ */ jsx(DocsLink, { path: "overview/device-authentication", title: "Device authentication" }),
    "."
  ] })
] });
var AuthButton = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  /* @__PURE__ */ jsx("h3", { children: "Authorize devices" }),
  /* @__PURE__ */ jsx("p", { children: "Expand this section to view the authentication options for this device. You can decide whether to accept it, reject it, or just dismiss this device for now." }),
  /* @__PURE__ */ jsxs("p", { children: [
    "See the documentation for more on ",
    /* @__PURE__ */ jsx(DocsLink, { path: "overview/device-authentication", title: "Device authentication" }),
    "."
  ] })
] });
var AddGroup = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  /* @__PURE__ */ jsx("h3", { children: "Device groups" }),
  /* @__PURE__ */ jsx("p", { children: "It is possible to create groups of devices. Once you have created a group and added one or more devices to it, you can deploy an update to that specific group only." })
] });
var ExpandArtifact = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  /* @__PURE__ */ jsx("h3", { children: "Device type compatibility" }),
  /* @__PURE__ */ jsxs("p", { children: [
    "Mender Artifacts have ",
    /* @__PURE__ */ jsx("b", { children: "Device types compatible" }),
    " as part of their metadata. All devices report which device type they are, as part of their inventory information. During a deployment, Mender makes sure that a device will only download and install an Artifact it is compatible with."
  ] }),
  /* @__PURE__ */ jsx("p", { children: "You can click on each Artifact in the Release to expand the row and view more information about it." }),
  /* @__PURE__ */ jsxs("p", { children: [
    "For more information on how to specify the device type compatibility and other artifact metadata,",
    " ",
    /* @__PURE__ */ jsx(DocsLink, { path: "artifact-creation/create-an-artifact", title: "see the documentation" }),
    "."
  ] })
] });
var DeviceSupportTip = () => /* @__PURE__ */ jsxs("p", { children: [
  "The steps in the guide should work on most operating systems in the Debian family (e.g. Debian, Ubuntu, Raspberry Pi OS) and devices based on ARMv6 or newer (e.g. Raspberry Pi 2/3/4, Beaglebone). Visit ",
  /* @__PURE__ */ jsx(DocsLink, { path: "overview/device-support", title: "our documentation" }),
  " for more information about device support."
] });
var ConfigureTimezoneTip = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  "To see the effects of applying a configuration to your device you can set one of the below values to modify the timezone of your device. While all values from ",
  /* @__PURE__ */ jsx("i", { children: "timedatectl list-timezones" }),
  " will work, to easily see the impact of the changed value you can use one of the following values:",
  /* @__PURE__ */ jsxs("ul", { children: [
    /* @__PURE__ */ jsx("li", { children: "Europe/Oslo" }),
    /* @__PURE__ */ jsx("li", { children: "America/Los_Angeles" }),
    /* @__PURE__ */ jsx("li", { children: "Asia/Tokyo" })
  ] }),
  "Once the configuration has been applied you can see the effect by opening the Remote Terminal to the device and executing the ",
  /* @__PURE__ */ jsx("i", { children: "date" }),
  " command."
] });
var ConfigureRaspberryLedTip = () => {
  const dispatch = useDispatch();
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    "To see the effects of applying a configuration to your device you can set one of the below values to modify the behaviour of your Raspberry Pi green status LED",
    /* @__PURE__ */ jsx(
      ConfigurationObject,
      {
        className: "margin-top-small margin-bottom-small",
        config: {
          mmc0: "The default, which blinks the led on storage activity",
          on: "Turn on the light permanently",
          off: "Turn off the light permanently",
          heartbeat: "Enable heartbeat blinking"
        },
        compact: true,
        setSnackbar: (...args) => dispatch(setSnackbar(...args))
      }
    ),
    "There are other possible values, but we won't advertise them here. See",
    /* @__PURE__ */ jsx("a", { href: "http://www.d3noob.org/2020/07/controlling-activity-led-on-raspberry-pi.html", target: "_blank", rel: "noopener noreferrer", children: "this blog post" }),
    " ",
    "or",
    " ",
    /* @__PURE__ */ jsx("a", { href: "https://www.raspberrypi.org/forums/viewtopic.php?t=273194#p1658930", target: "_blank", rel: "noopener noreferrer", children: "in the Raspberry Pi forums" }),
    " ",
    "for more information."
  ] });
};
var ConfigureAddOnTip = () => /* @__PURE__ */ jsxs("p", { children: [
  "Mender deploys the configuration attributes using the same mechanisms as software updates. The configuration is stored as a JSON file at",
  /* @__PURE__ */ jsx("code", { children: "/var/lib/mender-configure/device-config.json" }),
  " on the device and then all the scripts in",
  " ",
  /* @__PURE__ */ jsx("code", { children: "/usr/lib/mender-configure/apply-device-config.d/" }),
  " are executed to apply the configuration attributes. To add a new configuration attribute, you simply need to input it in the UI and add a script to that directory that applies it accordingly."
] });
var NameTagTip = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  "The ",
  /* @__PURE__ */ jsx("i", { children: "Name" }),
  " tag will be available as a device indentifier too."
] });
var NameFilterTip = () => /* @__PURE__ */ jsx(Fragment, { children: "Filtering by name is limited to devices with a previously defined name." });
var DeviceTypeTip = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  /* @__PURE__ */ jsxs("p", { children: [
    "If you don't see your exact device on the list, choose ",
    /* @__PURE__ */ jsx("i", { children: "Generic ARMv6 or newer" }),
    " to continue the tutorial for now."
  ] }),
  /* @__PURE__ */ jsxs("p", { children: [
    "(Note: if your device is ",
    /* @__PURE__ */ jsx("i", { children: "not" }),
    " based on ARMv6 or newer, the tutorial won't work - instead, go back and use the virtual device)"
  ] })
] });
var TwoFactorNote = ({ className }) => /* @__PURE__ */ jsx("div", { className, children: "Two Factor Authentication is enabled for your account. If you haven't set up a 3rd party authentication app with a verification code, please contact an administrator." });
var AuditlogExplanation = () => /* @__PURE__ */ jsx(Fragment, { children: "The audit log shows the history of changes made to your Devices, Artifacts, Deployments, and user management." });
var DashboardWidget = () => /* @__PURE__ */ jsx(Fragment, { children: "Add dashboard widgets to visualize the software distribution or geographical location of all your devices, or a group of your devices." });
var ScheduleDeployment = () => /* @__PURE__ */ jsx(Fragment, { children: "This time is relative to the server only \u2013 each device's time zone will not be taken into account. Devices across different time zones will receive the update at the same time." });
var GroupDeployment = () => /* @__PURE__ */ jsx(Fragment, { children: "The deployment will skip any devices in the group that are already on the target Release version, or that have an incompatible device type." });
var ForceDeployment = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  /* @__PURE__ */ jsx("h3", { children: "Force update" }),
  /* @__PURE__ */ jsx("p", { children: "This will make the Mender client install the update even if the selected release is already installed." })
] });
var ArtifactUpload = () => /* @__PURE__ */ jsx(Fragment, { children: "Upload an Artifact to an existing or new Release" });
var PhasedPausedDeployments = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  "This feature is not available on ",
  /* @__PURE__ */ jsx("b", { children: "phased deployments" }),
  ". If you'd like to set pause states between update steps, go back and adjust the rollout schedule to a ",
  /* @__PURE__ */ jsx("b", { children: "single phase" }),
  "."
] });
var ResetHistory = () => /* @__PURE__ */ jsx(Fragment, { children: "Greyed out items will not be considered during deployment roll out" });
var MenderArtifactUpload = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  "If there is no Release matching this Artifact\u2019s name, a new Release will be created for this Artifact.",
  /* @__PURE__ */ jsx("br", {}),
  /* @__PURE__ */ jsx("br", {}),
  "If there is already a Release matching this Artifact\u2019s name, the Artifact will be grouped in that Release."
] });
var SingleFileUpload = () => /* @__PURE__ */ jsx(Fragment, { children: "This will generate a single file application update Artifact, which requires some additional metadata to be entered." });
var GlobalSettings = () => /* @__PURE__ */ jsx(Fragment, { children: "These settings apply to all users, so changes made here may affect other users' experience." });
var Webhooks = () => /* @__PURE__ */ jsx(Fragment, { children: "Use webhooks to send data about device lifecycle events to third-party systems. Currently you can only have one integration set up at a time." });
var WebhookEvents = () => /* @__PURE__ */ jsx(Fragment, { children: "You can select which type(s) of events the webhook will receive. Device authentication includes when devices are provisioned, decommissioned, or authentication status changes." });
var WebhookSecret = () => /* @__PURE__ */ jsx(Fragment, { children: "The secret is used for signing the requests sent to your webhook, to verify their authenticity. It is optional, but highly recommended for security. The secret must be a hexidecimal string (including only characters from A-F and 0-9)." });
var TenantToken = () => /* @__PURE__ */ jsxs(Fragment, { children: [
  /* @__PURE__ */ jsx("h3", { children: "Organization token" }),
  "This token is unique for your organization and ensures that only devices that you own are able to connect to your account."
] });
var SsoMetadata = () => /* @__PURE__ */ jsx(Fragment, { children: "Submit the metadata document from your Identity Provider" });
var ReleaseName = () => /* @__PURE__ */ jsx(Fragment, { children: "If a Release with this name already exists, this new Artifact may be grouped into a Release with other Artifacts of the same name - so long as they are compatible with different device types" });
var TenantAdmin = () => /* @__PURE__ */ jsx(Fragment, { children: "Set the user who will have the admin role when this tenant is created. This can be a user who already has a Mender account, or a brand new user. The tenant admin will be able to change which user(s) have this role once they begin using the tenant." });
var SubTenantDeviceLimit = () => /* @__PURE__ */ jsx(Fragment, { children: "Set the maximum number of accepted devices this tenant can have connected to the server at any time. You can adjust this later. Each tenants\u2019 amount of accepted devices will count towards your total device limit." });
var SubTenantDeltaArtifactGeneration = () => /* @__PURE__ */ jsx(Fragment, { children: "This option will enable the server-side generation of Delta Artifacts for the created tenant when turned on" });
var SubTenantSSO = () => /* @__PURE__ */ jsx(Fragment, { children: "The created tenant will inherit the same Single Sign-On configuration as this Service Provider tenant. The created tenant\u2019s admin user will not be able to change the SSO settings later." });
var AttributeLimit = () => {
  const { isHosted } = useSelector(getFeatures);
  return isHosted ? /* @__PURE__ */ jsxs(Fragment, { children: [
    "Expand to see the list of attributes currently in use. Please",
    " ",
    /* @__PURE__ */ jsx("a", { href: "mailto:support@mender.io", target: "_blank", rel: "noopener noreferrer", children: "contact our team" }),
    " ",
    "if your use case requires a different set of attributes."
  ] }) : /* @__PURE__ */ jsx(Fragment, { children: "Expand to see the list of attributes currently in use." });
};
var TenantInitialAdmin = () => /* @__PURE__ */ jsx(Fragment, { children: "The user that was assigned as admin for this tenant when it was created. There is a chance the admin user will have changed or this user no longer exists in this tenant." });
var PlanUpgradeEmail = () => /* @__PURE__ */ jsx(Fragment, { children: "This email address will receive all payment receipts and notifications about pricing and device limits. It does not necessarily have to belong to a user in your Mender account" });
var HELPTOOLTIPS = {
  addGroup: { id: "addGroup", Component: AddGroup },
  artifactUpload: { id: "artifactUpload", Component: ArtifactUpload },
  attributeLimit: { id: "attributeLimit", Component: AttributeLimit },
  auditlogExplanation: { id: "auditlogExplanation", Component: AuditlogExplanation },
  authButton: { id: "authButton", Component: AuthButton },
  authExplainButton: { id: "authExplainButton", Component: AuthExplainButton },
  configureAddOnTip: { id: "configureAddOnTip", Component: ConfigureAddOnTip },
  configureRaspberryLedTip: {
    id: "configureRaspberryLedTip",
    Component: ConfigureRaspberryLedTip,
    isRelevant: ({ device = {} }) => {
      const { attributes = {} } = device;
      return ["raspberry", "rpi"].some((type) => attributes.device_type?.some((deviceType) => deviceType.startsWith(type)));
    }
  },
  configureTimezoneTip: {
    id: "configureTimezoneTip",
    Component: ConfigureTimezoneTip,
    isRelevant: ({ device = {} }) => {
      const { attributes = {} } = device;
      return ["raspberry", "rpi", "qemux86-64"].some((type) => attributes.device_type?.some((deviceType) => deviceType.startsWith(type)));
    }
  },
  dashboardWidget: { id: "dashboardWidget", Component: DashboardWidget },
  deviceSupportTip: { id: "deviceSupportTip", Component: DeviceSupportTip },
  deviceTypeTip: { id: "deviceTypeTip", Component: DeviceTypeTip },
  expandArtifact: { id: "expandArtifact", Component: ExpandArtifact },
  forceDeployment: { id: "forceDeployment", Component: ForceDeployment },
  globalSettings: { id: "globalSettings", Component: GlobalSettings },
  groupDeployment: { id: "groupDeployment", Component: GroupDeployment },
  menderArtifactUpload: { id: "menderArtifactUpload", Component: MenderArtifactUpload },
  nameFilterTip: { id: "nameFilterTip", Component: NameFilterTip },
  nameTagTip: { id: "nameTagTip", Component: NameTagTip },
  phasedPausedDeployments: { id: "phasedPausedDeployments", Component: PhasedPausedDeployments },
  planUpgradeEmail: { id: "planUpgradeEmail", Component: PlanUpgradeEmail },
  releaseName: { id: "releaseName", Component: ReleaseName },
  resetHistory: { id: "resetHistory", Component: ResetHistory },
  ssoMetadata: { id: "ssoMetadata", Component: SsoMetadata },
  scheduleDeployment: { id: "scheduleDeployment", Component: ScheduleDeployment },
  singleFileUpload: { id: "singleFileUpload", Component: SingleFileUpload },
  subTenantDeltaArtifactGeneration: { id: "subTenantDeltaArtifactGeneration", Component: SubTenantDeltaArtifactGeneration },
  subTenantDeviceLimit: { id: "subTenantDeviceLimit", Component: SubTenantDeviceLimit },
  subTenantSSO: { id: "subTenantSSO", Component: SubTenantSSO },
  tenantAdmin: { id: "tenantAdmin", Component: TenantAdmin },
  tenantInitialAdmin: { id: "tenantInitialAdmin", Component: TenantInitialAdmin },
  tenantToken: { id: "tenantToken", Component: TenantToken },
  twoFactorNote: { id: "twoFactorNote", SpecialComponent: TwoFactorNote },
  webhookEvents: { id: "webhookEvents", Component: WebhookEvents },
  webhooks: { id: "webhooks", Component: Webhooks },
  webhookSecret: { id: "webhookSecret", Component: WebhookSecret }
};
var MenderHelpTooltip = (props) => {
  const { id, contentProps = {} } = props;
  const tooltipsById = useSelector(getTooltipsState);
  const dispatch = useDispatch();
  const device = useSelector((state) => getDeviceById(state, contentProps.deviceId));
  const { readState = READ_STATES.unread } = tooltipsById[id] || {};
  const { Component, SpecialComponent, isRelevant = yes } = HELPTOOLTIPS[id];
  const onSetTooltipReadState = useCallback((...args) => dispatch(setTooltipReadState(...args)), [dispatch]);
  const onSetAllTooltipsReadState = (state) => dispatch(setAllTooltipsReadState(state));
  return /* @__PURE__ */ jsx(
    HelpTooltip,
    {
      setAllTooltipsReadState: onSetAllTooltipsReadState,
      setTooltipReadState: onSetTooltipReadState,
      device,
      tooltip: { Component, SpecialComponent, isRelevant, readState },
      ...props
    }
  );
};

export {
  HELPTOOLTIPS,
  MenderHelpTooltip
};
//# sourceMappingURL=chunk-ZIU5U7WL.js.map